Developers
==========

The current release is hosted on PyPI at https://pypi.python.org/pypi/pecos.

The software repository is hosted on GitHub at https://github.com/sandialabs/pecos.  

Automated testing is run using TravisCI at https://travis-ci.org/sandialabs/pecos.

Test coverage statistics are collected using Coveralls at https://coveralls.io/github/sandialabs/pecos.

Tests can be run locally using nosetests::

	nosetests -v --with-coverage --cover-package=pecos pecos

The development team includes:

* Katherine Klise, kaklise@sandia.gov
* Joshua Stein, jsstein@sandia.gov
